@@ -10,8 +10,8 @@ class Config():
     port: int = int(os.environ.get('PORT', '8080'))
     title: str = 'NiceGUI'
     reload: bool = True
-    favicon: str = 'favicon.ico'
+    favicon: Optional[str] = None
     dark: Optional[bool] = False
-    main_page_classes: str = 'q-ma-md column items-start'
+    main_page_classes: str = 'q-pa-md column items-start gap-4'
     binding_refresh_interval: float = 0.1
     excludes: List[str] = field(default_factory=list)
