@@ -1,7 +1,8 @@
+from ..routes import add_dependencies
 from .custom_view import CustomView
 from .element import Element
 
-CustomView.use(__file__)
+add_dependencies(__file__)
 
 
 class ColorsView(CustomView):
