@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from typing import List
+from typing import List, Union
 
 import justpy as jp
 
-from .. import globals
+from ..auto_context import get_view_stack
 from ..binding import active_links, bindable_properties, bindings
 from .element import Element
 
@@ -13,11 +13,11 @@ class Group(Element):
 
     def __enter__(self):
         self._child_count_on_enter = len(self.view)
-        globals.get_view_stack().append(self.view)
+        get_view_stack().append(self.view)
         return self
 
     def __exit__(self, *_):
-        globals.get_view_stack().pop()
+        get_view_stack().pop()
         if self._child_count_on_enter != len(self.view):
             self.update()
 
@@ -62,3 +62,8 @@ class Group(Element):
 
         self.view.delete_components()
         self.update()
+
+    def remove(self, element: Union[Element, int]) -> None:
+        view = element.view if isinstance(element, Element) else self.view.get_components()[element]
+        self.view.remove_component(view)
+        self.update()
