@@ -38,9 +38,13 @@ class Upload(Element):
             for form_data in msg.form_data:
                 if form_data.type == 'file':
                     files = [base64.b64decode(f.file_content) for f in form_data.files]
-                    arguments = UploadEventArguments(sender=self, socket=msg.websocket, files=files)
+                    names = [f.name for f in form_data.files]
+                    arguments = UploadEventArguments(sender=self, socket=msg.websocket, files=files, names=names)
                     if handle_event(self.upload_handler, arguments):
                         page_update = None
             return page_update
         except Exception:
             traceback.print_exc()
+
+    async def reset(self) -> None:
+        await self.page.run_javascript(f'document.getElementById({self.view.id}).reset()')
