@@ -1,20 +1,23 @@
 import traceback
 from dataclasses import dataclass
 from inspect import signature
-from typing import Any, Callable, List, Optional
+from typing import TYPE_CHECKING, Any, Callable, List, Optional
 
 from starlette.websockets import WebSocket
 
 from . import globals
-from .elements.element import Element
+from .auto_context import Context
 from .helpers import is_coroutine
 from .lifecycle import on_startup
 from .task_logger import create_task
 
+if TYPE_CHECKING:
+    from .elements.element import Element
+
 
 @dataclass
 class EventArguments:
-    sender: Element
+    sender: 'Element'
     socket: Optional[WebSocket]
 
 
@@ -38,6 +41,7 @@ class MouseEventArguments(EventArguments):
 @dataclass
 class UploadEventArguments(EventArguments):
     files: List[bytes]
+    names: List[str]
 
 
 @dataclass
@@ -225,17 +229,22 @@ class KeyEventArguments(EventArguments):
     modifiers: KeyboardModifiers
 
 
+@dataclass
+class PageEvent:
+    socket: WebSocket
+
+
 def handle_event(handler: Optional[Callable], arguments: EventArguments) -> Optional[bool]:
     try:
         if handler is None:
             return False
         no_arguments = not signature(handler).parameters
-        with globals.within_view(arguments.sender.parent_view):
+        with Context(arguments.sender.parent_view):
             result = handler() if no_arguments else handler(arguments)
         if is_coroutine(handler):
             async def wait_for_result():
-                with globals.within_view(arguments.sender.parent_view):
-                    await result
+                with Context(arguments.sender.parent_view) as context:
+                    await context.watch_asyncs(result)
             if globals.loop and globals.loop.is_running():
                 create_task(wait_for_result(), name=str(handler))
             else:
