@@ -15,6 +15,7 @@ if TYPE_CHECKING:
 class PageBuilder:
     function: Callable[[], Awaitable['Page']]
     shared: bool
+    favicon: Optional[str] = None
 
     _shared_page: Optional['Page'] = None
 
@@ -26,7 +27,7 @@ class PageBuilder:
         if self.shared:
             while self._shared_page is None:
                 await asyncio.sleep(0.05)
-            return self._shared_page
+            page = self._shared_page
         else:
             page: Page = await self.function(request)
         return await page._route_function(request)
