@@ -20,9 +20,9 @@ def run(self, *,
         host: str = os.environ.get('HOST', '0.0.0.0'),
         port: int = int(os.environ.get('PORT', '8080')),
         title: str = 'NiceGUI',
-        favicon: str = 'favicon.ico',
+        favicon: Optional[str] = None,
         dark: Optional[bool] = False,
-        main_page_classes: str = 'q-ma-md column items-start',
+        main_page_classes: str = 'q-pa-md column items-start gap-4',
         binding_refresh_interval: float = 0.1,
         show: bool = True,
         reload: bool = True,
